# remirepo spec file for php-pecl-translit
#
# Copyright (c) 2015-2023 Remi Collet
# License: CC-BY-SA-4.0
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-pecl-translit}

%bcond_without      tests

%global pecl_name   translit
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
# After 20-iconv
%global ini_name    40-%{pecl_name}.ini
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:      Transliterates non-latin character sets to latin
Name:         %{?scl_prefix}php-pecl-%{pecl_name}
Version:      0.7.1
Release:      2%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:      BSD-2-Clause
URL:          https://pecl.php.net/package/%{pecl_name}

Source0:      https://pecl.php.net/get/%{sources}.tgz

BuildRequires: %{?dtsprefix}gcc
BuildRequires: make
BuildRequires: %{?scl_prefix}php-devel > 7
BuildRequires: %{?scl_prefix}php-pear
%if %{with tests}
BuildRequires: %{?scl_prefix}php-iconv
%endif

Requires:     %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:     %{?scl_prefix}php(api) = %{php_core_api}

Provides:     %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:     %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:     %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:     %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}


%description
This extension allows you to transliterate text in non-latin characters
(such as Chinese, Cyrillic, Greek etc) to latin characters.  Besides the
transliteration the extension also contains filters to upper- and lowercase
latin, cyrillic and greek, and perform special forms of transliteration such
as converting ligatures such as the Norwegian 'æ' to 'ae' and normalizing
punctuation and spacing.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -c -q

%{?_licensedir:sed -e '/LICENSE/s/role="doc"/role="src"/' -i package.xml}

cd %{sources}
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_TRANSLIT_VERSION/{s/.* "//;s/".*$//;p}' php_translit.h)
if test "x${extver}" != "x%{version}%{?prever}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}

cd ../NTS
%configure  \
  --enable-translit \
  --with-php-config=%{__phpconfig}
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%configure  \
  --enable-translit \
  --with-php-config=%{__ztsphpconfig}
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# Drop in the bit of configuration
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 %{sources}/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
[ -f %{php_extdir}/iconv.so ] && DEPMOD="-d extension=iconv.so"

: Minimal load test for NTS extension
%{__php} -n \
    $DEPMOD \
    -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    -m | grep '^%{pecl_name}$'

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} -n \
    $DEPMOD \
    -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    -m | grep '^%{pecl_name}$'
%endif

%if %{with tests}
cd %{sources}
%if "%{php_version}" > "7.4"
TEST_OPTS="-q %{?_smp_mflags} --show-diff"
%else
TEST_OPTS="-q --show-diff"
%endif

: Upstream test suite NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n $DEPMOD -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php $TEST_OPTS

%if %{with_zts}
: Upstream test suite NTS extension
TEST_PHP_EXECUTABLE=%{__ztsphp} \
TEST_PHP_ARGS="-n $DEPMOD -d extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__ztsphp} -n run-tests.php $TEST_OPTS
%endif
%endif



%files
%{!?_licensedir:%doc %{pecl_docdir}/%{pecl_name}}
%{?_licensedir:%license %{sources}/LICENSE}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Sep  4 2023 Remi Collet <remi@remirepo.net> - 0.7.1-2
- build out of sources tree

* Thu Oct  1 2020 Remi Collet <remi@remirepo.net> - 0.7.1-1
- update to 0.7.1
- drop patch merged upstream

* Mon Feb 24 2020 Remi Collet <remi@remirepo.net> - 0.7.0-5
- add patch for PHP 8 from
  https://github.com/derickr/pecl-translit/pull/8

* Mon Feb 24 2020 Remi Collet <remi@remirepo.net> - 0.7.0-4
- update to 0.7.0
- raise dependency on PHP 7.0
- sources from PECL

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.6.3-4
- rebuild for 7.4.0RC1

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 0.6.3-3
- rebuild for 7.4.0beta1

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 0.6.3-2
- rebuild

* Wed May 29 2019 Remi Collet <remi@remirepo.net> - 0.6.3-1
- update to 0.6.3
- raise dependency on PHP 5.6

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.6.2-8
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.6.2-7
- rebuild for 7.3.0alpha4 new ABI

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 0.6.2-6
- rebuild for PHP 7.2.0beta1 new API

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 0.6.2-5
- rebuild with PHP 7.1.0 GA

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 0.6.2-4
- rebuild for PHP 7.1 new API version

* Thu Jun  9 2016 Remi Collet <remi@fedoraproject.org> - 0.6.2-3
- fix license installation on EL-6

* Sun Mar  6 2016 Remi Collet <remi@fedoraproject.org> - 0.6.2-2
- adapt for F24

* Sat Nov 28 2015 Remi Collet <remi@fedoraproject.org> - 0.6.2-1
- Initial package, version 0.6.2 (beta)

